# eric7.QScintilla.SortOptionsDialog

Module implementing a dialog to enter the sort options for a line sort.

### Global Attributes

None

### Classes

SortOptionsDialog | Class implementing a dialog to enter the sort options for a line sort.

### Functions

None

## SortOptionsDialog

Class implementing a dialog to enter the sort options for a line sort.

### Derived from

QDialog, Ui_SortOptionsDialog

### Class Attributes

None

### Class Methods

None

### Methods

SortOptionsDialog | Constructor
getData | Public method to get the selected options.

### Static Methods

None

#### SortOptionsDialog (Constructor)

SortOptionsDialog(parent=None)

Constructor

parent (QWidget)
  reference to the parent widget

#### SortOptionsDialog.getData

getData()

Public method to get the selected options.

Return:
  tuple of three flags indicating ascending order, alphanumeric sort and case sensitivity

Return Type:
  tuple of (bool, bool, bool)

Up